geowatch.tasks.invariants.fit\_segment module
=============================================

.. automodule:: geowatch.tasks.invariants.fit_segment
   :members:
   :undoc-members:
   :show-inheritance:
